pamqp
=====
pamqp is a low level AMQP 0-9-1 frame encoding and decoding library for Python 3.

pamqp is not a end-user client library for talking to RabbitMQ but rather is
used by client libraries for marshaling and unmarshaling AMQP frames.

|Version| |Status| |Coverage| |License| |Maintainability| |Downloads|

Documentation
-------------
https://pamqp.readthedocs.io

Python Versions Supported
-------------------------
3.6+

License
-------
Copyright (c) 2011-2020 Gavin M. Roy
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.
* Neither the name of the copyright holder nor the names of its contributors may
  be used to endorse or promote products derived from this software without
  specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

.. |Version| image:: https://img.shields.io/pypi/v/pamqp.svg?
   :target: https://pypi.python.org/pypi/pamqp

.. |Status| image:: https://github.com/gmr/pamqp/workflows/Testing/badge.svg?
   :target: https://github.com/gmr/pamqp/actions?workflow=Testing
   :alt: Build Status

.. |Coverage| image:: https://img.shields.io/codecov/c/github/gmr/pamqp.svg?
   :target: https://codecov.io/github/gmr/pamqp?branch=master

.. |License| image:: https://img.shields.io/pypi/l/pamqp.svg?
   :target: https://pamqp.readthedocs.org

.. |Maintainability| image:: https://api.codeclimate.com/v1/badges/9efbb0957abb036254a1/maintainability
   :target: https://codeclimate.com/github/gmr/pamqp

.. |Downloads| image:: https://img.shields.io/pypi/dm/pamqp
   :target: https://pypi.org/project/pamqp/
